@@ -6,6 +6,8 @@ import sys
 
 from time import sleep
 
+import threading
+
 
 class Slot(comb.slot.Slot):
     def initialize(self):
@@ -48,8 +50,8 @@ class Slot(comb.slot.Slot):
             print("prepare todo_list, from 1,1000")
 
         print("current threads set:%d,cycle is %d,cycle_max is %d" % (self.threads_num, self.sleep, self.sleep_max))
-        print("slot will sleep 5 second.")
-        sleep(5)
+        print("slot start now,will sleep 2 second.")
+        sleep(2)
         print("slot will pop up todo list.sleep 2 second.")
         sleep(2)
         print(self.todo_list)
